osqp_python: The Operator Splitting QP Solver (Python wrapper)
==============================================================

Description
-----------

This is the Python wrapper for OSQP: The Operator Splitting QP Solver.

It vendors OSQP.

License
-------

Apache 2.0

Upstream Contact
----------------

https://pypi.org/project/osqp/

